==> core_main_app-1.10.2.tar.gz: core_main_app-1.10.2/core_main_app/static/core_main_app/common/js/notify-styles.js <==
$.notify.addStyle(
    'default', {
        html: "<div><i class='fa fa-info-circle'/> <span data-notify-text/></div>",
        classes: {
			base: {
				"padding": "8px 15px",
				"font-size": "1.1em",
				"color": "#3A87AD",
				"background-color": "#D9EDF7",
				"border": "1px solid #BCE8F1",
				"border-radius": "4px",
				"white-space": "nowrap"
			}
        }
});

$.notify.addStyle(
    'success', {
        html: "<div><i class='fa fa-check-circle'/> <span data-notify-text/></div>",
        classes: {
			base: {
				"padding": "8px 15px",
				"font-size": "1.1em",
				"color": "#468847",
				"background-color": "#DFF0D8",
				"border": "1px solid #D6E9C6",
				"border-radius": "4px",
				"white-space": "nowrap"
			}
        }
});

$.notify.addStyle(
    'info', {
        html: "<div><i class='fa fa-info-circle'/> <span data-notify-text/></div>",
        classes: {
			base: {
				"padding": "8px 15px",
				"font-size": "1.1em",
				"color": "#3A87AD",
				"background-color": "#D9EDF7",
				"border": "1px solid #BCE8F1",
				"border-radius": "4px",
				"white-space": "nowrap"
			}
        }
});

$.notify.addStyle(
    'warning', {
        html: "<div><i class='fa fa-exclamation-triangle'/> <span data-notify-text/></div>",
        classes: {
			base: {
				"padding": "8px 15px",
				"font-size": "1.1em",
				"color": "#C09853",
				"background-color": "#FCF8E3",
				"border": "1px solid #FBEED5",
				"border-radius": "4px",
				"white-space": "nowrap"
			}
        }
});

$.notify.addStyle(
    'error', {
        html: "<div><i class='fa fa-exclamation-circle'/> <span data-notify-text/></div>",
        classes: {
			base: {
				"padding": "8px 15px",
				"font-size": "1.1em",
				"color": "#B94A48",
				"background-color": "#F2DEDE",
				"border": "1px solid #EED3D7",
				"border-radius": "4px",
				"white-space": "nowrap"
			}
        }
});

==> core_main_app-2.1.0.tar.gz: core_main_app-2.1.0/core_main_app/static/core_main_app/common/js/notify-styles.js <==
$.notify.addStyle(
    'default', {
        html: "<div><i class='fas fa-info-circle'/> <span data-notify-text/></div>",
        classes: {
			base: {
				"padding": "8px 15px",
				"font-size": "1.1em",
				"color": "#3A87AD",
				"background-color": "#D9EDF7",
				"border": "1px solid #BCE8F1",
				"border-radius": "4px",
				"white-space": "nowrap"
			}
        }
});

$.notify.addStyle(
    'success', {
        html: "<div><i class='fas fa-check-circle'/> <span data-notify-text/></div>",
        classes: {
			base: {
				"padding": "8px 15px",
				"font-size": "1.1em",
				"color": "#468847",
				"background-color": "#DFF0D8",
				"border": "1px solid #D6E9C6",
				"border-radius": "4px",
				"white-space": "nowrap"
			}
        }
});

$.notify.addStyle(
    'info', {
        html: "<div><i class='fas fa-info-circle'/> <span data-notify-text/></div>",
        classes: {
			base: {
				"padding": "8px 15px",
				"font-size": "1.1em",
				"color": "#3A87AD",
				"background-color": "#D9EDF7",
				"border": "1px solid #BCE8F1",
				"border-radius": "4px",
				"white-space": "nowrap"
			}
        }
});

$.notify.addStyle(
    'warning', {
        html: "<div><i class='fas fa-exclamation-triangle'/> <span data-notify-text/></div>",
        classes: {
			base: {
				"padding": "8px 15px",
				"font-size": "1.1em",
				"color": "#C09853",
				"background-color": "#FCF8E3",
				"border": "1px solid #FBEED5",
				"border-radius": "4px",
				"white-space": "nowrap"
			}
        }
});

$.notify.addStyle(
    'error', {
        html: "<div><i class='fas fa-exclamation-circle'/> <span data-notify-text/></div>",
        classes: {
			base: {
				"padding": "8px 15px",
				"font-size": "1.1em",
				"color": "#B94A48",
				"background-color": "#F2DEDE",
				"border": "1px solid #EED3D7",
				"border-radius": "4px",
				"white-space": "nowrap"
			}
        }
});
